@@ -67,7 +67,8 @@ char *rm_uservar[MAX_LINELEN+1],*rm_userfn[MAX_LINELEN+1];
 int  rm_uservars,rm_userfns;
 
 /* add user-defined variables and function names,
- * internal, only called by rawmath(). */
+ * internal, only called by rawmath().
+ */
 void getuservar(void)
 {
     char *p1, *p2, *p;
@@ -114,7 +115,7 @@ char *mathname_split(char *p)
       c++; goto beg;
     }
     for(i=mathname_no-1;
-      i>=0 && 
+      i>=0 &&
       (strncmp(p,mathname[i].name,strlen(mathname[i].name))!=0
       || mathname[i].style==RM_PREFIX);
       i--);
@@ -123,19 +124,19 @@ char *mathname_split(char *p)
       j=strlen(mathname[i].name);
       goto gotit;
     }
-    for(i=0;i<rm_uservars && 
+    for(i=0;i<rm_uservars &&
       strncmp(rm_uservar[i],p,strlen(rm_uservar[i]));i++);
     if(i<rm_uservars) {
       type=RM_VAR;
       j=strlen(rm_uservar[i]); goto gotit;
     }
-    for(i=0;i<rm_userfns && 
+    for(i=0;i<rm_userfns &&
       strncmp(p,rm_userfn[i],strlen(rm_userfn[i]));i++);
     if(i<rm_userfns) {
       type=RM_FN;
       j=strlen(rm_userfn[i]); goto gotit;
     }
-    return NULL;    
+    return NULL;
 }
 
 int __replace_badchar (char *p, char *old, char *new)
@@ -143,14 +144,14 @@ int __replace_badchar (char *p, char *old, char *new)
   char *p1 ;
   while((p1=strstr(p,old))!=NULL) {
     string_modify(p,p1,p1+strlen(old),"%s",new);
-    cnt++; 
+    cnt++;
   }
   return cnt ;
 }
 
 /* translate |x| into abs(x)*/
 int __replace_abs ( char *p )
-{  
+{
     char *p1, *p2 ;
     while((p1=strchr(p,'|'))!=NULL) {
       p2=find_matching(p1+1,'|');
@@ -162,7 +163,7 @@ int __replace_abs ( char *p )
 
 /* signs: translate ++, +-, -+, ... into one sign. */
 void __replace_plusminus ( char *p )
-{ 
+{
    char *p1, *p2;
    for(p1=p;*p1!=0;p1++) {
      int sign, redundant;
@@ -182,10 +183,10 @@ void __replace_plusminus ( char *p )
 }
 
 /* dangling decimal points
-4. --> 4.0  4.x -> 4.0x
-.5 -> 0.5
-another treatment is done in insmath (will replace .. by , )
-*/
+ * 4. --> 4.0  4.x -> 4.0x
+ * .5 -> 0.5
+ * another treatment is done in insmath (will replace .. by , )
+ */
 void __treat_decimal(char *p)
 { char *p1 ;
   for(p1=strchr(p,'.'); p1!=NULL; p1=strchr(p1+1,'.')) {
@@ -207,7 +208,7 @@ void __treat_decimal(char *p)
 
 /* replace new-lines, tabs, " */
 void __replace_space(char *p)
-{ 
+{
  char *p1 ;
  for(p1=p;*p1!=0; p1++) {
     if(*p1=='\\' || isspace(*p1)) *p1=' ';// replace \ and all spaces by a simple space -
@@ -215,17 +216,17 @@ void __replace_space(char *p)
   }
 }
 
-    /* Error-tolerante raw math translation routine 
-     * Translate error-laden raw math into machine-understandable form.
-     * do nothing if there is some { or \\ 
-     */ 
+/* Error-tolerante raw math translation routine
+ * Translate error-laden raw math into machine-understandable form.
+ * do nothing if there is some { or \\
+ */
 void rawmath(char *p)
 {
     char *p1, *p2, *p3, *p4;
     char warnbuf[1024];
     int ambiguous=0,unknown=0,flatpower=0,badprec=0,unmatch=0;// for warning
 
-    /* looks like a TeX source : do nothing */
+/* looks like a TeX source : do nothing */
     if( (strchr(p,'\\')!=NULL || strchr(p,'{')!=NULL)) return;
     if(strchr(p,'^')==NULL) flatpower=-1;
     if(strlen(p)>=MAX_LINELEN) {*p=0; return;}
@@ -236,12 +237,12 @@ void rawmath(char *p)
     if (__replace_badchar(p,"", "^2 ")) flatpower=1;
     if (__replace_badchar(p,"", "^3 ")) flatpower=1;
     unmatch=__replace_abs(p);
-    __replace_plusminus(p) ; 
+    __replace_plusminus(p) ;
     __replace_space(p);
     __treat_decimal(p);
     if (rawmath_easy) return;
 
-        /* Principal translation: justapositions to multiplications */
+/* Principal translation: justapositions to multiplications */
     if(strstr(p,"^1/")!=NULL) badprec=1;
     getuservar();
     for(p1=p;*p1;p1++) {
@@ -269,7 +270,7 @@ void rawmath(char *p)
         if(i>=0 && get_evaltype(i)>0) {
           fnname1:
           p1=p2;p2=p3;
-        /*fnname:*/
+/*fnname:*/
           if(*p2 && *p2!='(' && *p2!='*' && *p2!='/') {
             char hatbuf[MAX_LINELEN+1];
             hatbuf[0]=')'; hatbuf[1]=0;
@@ -322,12 +323,12 @@ void rawmath(char *p)
           switch(mathname[i].style) {
             case RM_FN:
               goto fnname1;
-            
+
             case RM_VAR:
               p1=p2;p2=p3; goto add_star;
-            
+
             case RM_PREFIX:
-              if(*p3!='c' && *p3!='s' && *p3!='t' && 
+              if(*p3!='c' && *p3!='s' && *p3!='t' &&
              *p3!='C' && *p3!='S' && *p3!='T') break;
               ambiguous=1;
               ovlstrcpy(p2,p3); p1--; continue;
@@ -349,11 +350,11 @@ void rawmath(char *p)
           string_modify(p,p1,p2,"%s",buf);
           p1--; continue;
         }
-         /* unknown name */
+/* unknown name */
         ambig: p1=p2;p2=p3;
         if(strlen(buf)>1) {
           for(p3=buf;*p3!=0 && !myisdigit(*p3);p3++);
-          if(*p3!=0 && flatpower!=0) flatpower=1; 
+          if(*p3!=0 && flatpower!=0) flatpower=1;
           else {
             unknown=1;
             force_setvar("wims_warn_rawmath_parm",buf);
@@ -386,10 +387,12 @@ void rawmath(char *p)
     }
 }
 
- /*  replace < and > by html code if htmlmath_gtlt=yes - is only used in deduc - not documented*/
-void __replace_htmlmath_gtlt (char *p) 
+ /* replace < and > by html code if htmlmath_gtlt=yes
+  * is only used in deduc - not documented
+  */
+void __replace_htmlmath_gtlt (char *p)
 {   char *pp;
-    char *p1=getvar("htmlmath_gtlt"); 
+    char *p1=getvar("htmlmath_gtlt");
     if(p1!=NULL && strcmp(p1,"yes")==0) {
       for(pp=strchr(p,'<'); pp!=NULL; pp=strchr(pp+1,'<'))
       string_modify(p,pp,pp+1,"&lt;");
@@ -398,16 +401,17 @@ void __replace_htmlmath_gtlt (char *p)
    }
 }
 
-/* exponents or indices : 
+/* exponents or indices :
  *  all digits or + or - following a ^ or _ are considered as in exponent/subscript
  *  expression with ( ) following a ^ or _ are  considered as in exponent/subscript
  *  the parenthesis are suppressed except in case of exponent and only digits.
- *  if int n != 0, use html code, else use tex code */
+ *  if int n != 0, use html code, else use tex code
+ */
 void __replace_exponent(char *p, int n)
 {
    char *p1;
    char *SUPBEG, *SUPEND;
-   if (n) { SUPBEG = "<sup>"; SUPEND = "</sup>";} 
+   if (n) { SUPBEG = "<sup>"; SUPEND = "</sup>";}
    else { SUPBEG = "^{"; SUPEND = "}";}
 
     for(p1=strchr(p,'^');p1!=NULL;p1=strchr(p1+1,'^')) {
@@ -416,8 +420,13 @@ void __replace_exponent(char *p, int n)
         p3 = p2 = find_word_start(p1+1);
         if(*p2=='+' || *p2=='-') p2++;
         p2 = find_word_start(p2);
-        if(*p2=='(') { /* ^[+-]( */
-            p2 = find_matching(p2+1,')');
+/* jm.evers 31.1.2014
+ * add '}' to recognized parenthesis in exponent
+ * !mathmlmath 2 \cdot x^{3} will now produce correct exponent...
+ * !mathmlmath should convert LaTeX input into correct MathML
+ */
+        if(*p2=='(' || *p2 == '{') { /* ^[+-]( */
+             if(*p2 == '('){ p2 = find_matching(p2+1,')');}else { if(*p2 == '{'){ p2 = find_matching(p2+1,'}');}}
             /* no matching ')' : p2 = end of line; otherwise just after ')' */
             if (p2==NULL) p2=p+strlen(p); else p2++;
             /* ^( followed by any number of digits/letters, up to p2
@@ -425,14 +434,15 @@ void __replace_exponent(char *p, int n)
             /* do we remove parentheses containing exponent group ? */
             if (*p3=='(') for(pp=p3+1;pp<p2-1;pp++) {
                 if(!isalnum(*pp)) {
-                    /* not a digit/letter. Remove (). */ 
+                    /* not a digit/letter. Remove (). */
                     p3++;*(p2-1)=0;break;
                 }
                 /* x^(2), parentheses not removed */
             }
-            /* p3: start of word after ^ */
-            /* matching parentheses from exponent group. : f^(4) 4-derivative */
-            /* don't  ignore / remove a leading + sign in exponent group : Cu^+ */
+/* p3: start of word after ^
+ * matching parentheses from exponent group. : f^(4) 4-derivative
+ * don't  ignore / remove a leading + sign in exponent group : Cu^+
+ */
         } else { /* ^[+-] */
             char *ptt=p2;
             p2=find_word_start(find_mathvar_end(p2));
@@ -442,16 +452,18 @@ void __replace_exponent(char *p, int n)
                 p2t=find_matching(p2+1,')'); if(p2t!=NULL) p2=p2t+1;
                 /* FIXME: what if no matching ) ? */
             }
-            /* ^[+-]var(...): p2 points after closing ')' */
-            /* FIXME: I don't think this 'else' branch is sensible. One
-             * should NOT accept x^b(c+1) as meaning x^[b(c+1)]. I would
-             * remove it altogether. */
+/* ^[+-]var(...): p2 points after closing ')'
+ * FIXME: I don't think this 'else' branch is sensible. One
+ * should NOT accept x^b(c+1) as meaning x^[b(c+1)]. I would
+ * remove it altogether.
+ */
         }
-        /* p1 points at ^ before exponent group */
-        /* p2 points at end of exponent group */
-        /* p3 = exponent group (sometimes stripped, without parentheses) */
-
-        /* truncate string p at p2 [ c = char deleted by truncation ] */
+/* p1 points at ^ before exponent group
+ * p2 points at end of exponent group
+ * p3 = exponent group (sometimes stripped, without parentheses)
+ *
+ * truncate string p at p2 [ c = char deleted by truncation ]
+ */
         c = *p2;if(c!=0) *p2++=0;
         /* replace ^<exponent group>. Add back missing character 'c' */
         string_modify(p,p1,p2, "%s%s%s%c",SUPBEG,p3,SUPEND,c);
@@ -463,7 +475,7 @@ void __replace_subscript(char *p, int n)
 {
    char *p1, *p2;
    char *SUBBEG, *SUBEND;
-   if (n) {SUBBEG = "<sub>"; SUBEND = "</sub>";} 
+   if (n) {SUBBEG = "<sub>"; SUBEND = "</sub>";}
    else {SUBBEG = "_{"; SUBEND = "}";}
    for(p1=strchr(p,'_');p1!=NULL;p1=strchr(p1+1,'_')) {
      char buff[256];
@@ -479,7 +491,7 @@ void __replace_subscript(char *p, int n)
 
 /* get rid of 1*.. ..*1  exemple : 1 * x, x/1 */
 void __replace_getrid1 (char *p)
-{   char *p1, *p2, *p3 ; 
+{   char *p1, *p2, *p3 ;
     for(p1=p;*p1;p1++) {
       if(*p1!='1') continue;
       if(myisdigit(*(p1+1)) || *(p1+1)=='.' ||
@@ -487,12 +499,12 @@ void __replace_getrid1 (char *p)
       p2=find_word_start(p1+1);
       if(p1>p+2 && (*(p1-1)=='-' || *(p1-1)=='+')) {
         for(p3=p1-2; p3>p && isspace(*p3); p3--);
-        if(p3>p+1 && (*p3=='E' || *p3=='e')) { /* ??? */ 
+        if(p3>p+1 && (*p3=='E' || *p3=='e')) { /* ??? */
         p3--; while(p3>p && isspace(*p3)) p3--;
         if(myisdigit(*p3) || *p3=='.') continue;
         }
       }
-      if(p1==p) p3="+"; 
+      if(p1==p) p3="+";
       else for(p3=p1-1;p3>p && isspace(*p3);p3--);
       if(*p2=='*' && *p3!='/') {/* delete 1 if 1* or /1 */
         ovlstrcpy(p1,p2+1);continue;
@@ -523,21 +535,22 @@ void __replace_getridstar (char *p)
   }
 }
 
-/* <=, >=, ->, =>, <=> 
- * if int n != 0, use html code, else use tex code */
+/* <=, >=, ->, =>, <=>
+ * if int n != 0, use html code, else use tex code
+ */
 
 void __replace_arrow ( char *p, int n)
 {   char *p1, *p2, *m_prefix;
     if (n) m_prefix="$m_"; else m_prefix="\\";
-    
+
     for(p1=strstr(p,"&lt;="); p1!=NULL; p1=strstr(p1+1,"&lt;=")) {
-      if(*(p1+5)!='&' && *(p1+5)!='=') 
+      if(*(p1+5)!='&' && *(p1+5)!='=')
         string_modify(p,p1,p1+5, "%sle",m_prefix);
       else {
           for(p2=p1+5; *p2=='='; p2++);
           if(strncmp(p2,"&gt;",4)==0) {
-            if(p2>p1+5) { string_modify(p,p1,p2+4,"%sLongleftrightarrow",m_prefix);} 
-            else { string_modify(p,p1,p2+4,"%sLeftrightarrow",m_prefix);} 
+            if(p2>p1+5) { string_modify(p,p1,p2+4,"%sLongleftrightarrow",m_prefix);}
+            else { string_modify(p,p1,p2+4,"%sLeftrightarrow",m_prefix);}
           }
           else { string_modify(p,p1,p2,"%sLongleftarrow",m_prefix);}
       }
@@ -566,7 +579,7 @@ void __replace_arrow ( char *p, int n)
 
 /* why <tt> is used sometimes ? replace single characters by italics one
  * is it useful in mathml ?
-*/
+ */
 void __replace_italics (char *p, int n)
 { char *p1, *p2, *p3, pbuf[16];
   char *ITBEG, *ITEND, *ITtBEG, *ITtEND;
@@ -577,7 +590,7 @@ void __replace_italics (char *p, int n)
      ITBEG = "" ; ITtBEG = "";
      ITEND = ""; ITtEND = "";
   }
-  
+
   for(p1=p;*p1;p1++) {
     if(*p1=='<') {
         p1=strchr(p1,'>'); if(p1==NULL) break; //recognize an html tag < >
@@ -609,11 +622,12 @@ void __replace_italics (char *p, int n)
 
 /* float (1.2 E-03) : 3E+021 -> 3  10^{21} - 3E-21 -> 3  10^{-21}
  * or replace variable name (alpha)
- * if int n != 0, use html code, else use tex code */
+ * if int n != 0, use html code, else use tex code
+ */
 void __replace_mathvar(char *p,int n)
 { char *p1, *p2, *p3;
   char *EXPBEG, *EXPEND, *EXPBEGMINUS, *SUBBEG, *SUBEND, *m_prefix;
-  
+
   if ( n ) {
      EXPBEG = " &times; 10<sup>";
      EXPBEGMINUS = " &times; 10<sup>-";
@@ -631,15 +645,16 @@ void __replace_mathvar(char *p,int n)
   }
   for (p1=find_mathvar_start(p);*p1!=0;p1=find_mathvar_start(p2)) {
     char buf[MAX_LINELEN+1];
-    /* if the variable is preceded by \ do nothing - in fact this should not arrive
-    */ 
-    if (p1>p && *(p1-1) == '\\' ) break ; 
+/* if the variable is preceded by \ do nothing
+ * in fact this should not arrive
+ */
+    if (p1>p && *(p1-1) == '\\' ) break ;
     p2 = find_mathvar_end(p1);
         if (p1 == p2) break;
     memmove(buf,p1,p2-p1);buf[p2-p1]=0;
 
     if(myisdigit(buf[0])) {
-            /* number : 3E+021 -> 3 x 10^{21} - 3E-21 -> 3 x 10^{-21} */
+/* number : 3E+021 -> 3 x 10^{21} - 3E-21 -> 3 x 10^{-21} */
         int k = 1, minus = 0;
 
 /* see putnumber in texmath.c*/
@@ -654,8 +669,9 @@ void __replace_mathvar(char *p,int n)
         string_modify(p,p2,p2, EXPEND);
         p2 += strlen(EXPEND);
     } else {
-            /* alphabetic name, replace greek letters and symbols in hmname*/
-            /* not done in texmath.c*/
+/* alphabetic name, replace greek letters and symbols in hmname
+ * not done in texmath.c
+ */
         int i = search_list(hmname,hmname_no,sizeof(hmname[0]),buf);
         char *n, *r;
         if(i<0) { /* not in list */
@@ -681,8 +697,9 @@ void __replace_mathvar(char *p,int n)
   }
 }
 
-/* translate raw math expression coming from calculators into best html way 
- * if int n != 0, use html code, else use tex code */
+/* translate raw math expression coming from calculators into best html way
+ * if int n != 0, use html code, else use tex code
+ */
 void __htmlmath(char *p,int n)
 {
     if(!rawmath_easy) { rawmath_easy=1; rawmath(p); rawmath_easy=0;}
@@ -700,14 +717,14 @@ void __htmlmath(char *p,int n)
    strip_trailing_spaces(p);
 }
 
-void htmlmath(char *p) 
+void htmlmath(char *p)
 {
  __htmlmath(p,1) ;
 }
 
 /* if mathml is closed, it will be just htmlmath*/
 
-void mathmlmath(char *p) 
-{ 
+void mathmlmath(char *p)
+{
     if (mathalign_base == 2) { __htmlmath(p,0) ; mathml(p,1);} else { __htmlmath(p,1) ;}
 }
